<h2>oas-mini</h2>

Utilitário de linha de comando para chamar endpoints relacionados ao Portal OAS.
<a href="https://fontes.intranet.bb.com.br/oas/oas-mini/-/wikis/home">Acesse aqui a documentação</a>.
